@@ -6,8 +6,8 @@ in PDF files, and for handling PDF-specific document signing needs.
 
 from .functions import async_sign_pdf, sign_pdf
 
-from .pdf_cms import SimpleSigner
-from .pdf_signer import PdfSignatureMetadata
+from .pdf_cms import SimpleSigner, ExternalSigner
+from .pdf_signer import PdfSignatureMetadata, PdfTimeStamper
 
 from .constants import (
     DEFAULT_MD,
@@ -15,7 +15,9 @@ from .constants import (
 
 __all__ = [
     'SimpleSigner',
+    'ExternalSigner',
     'PdfSignatureMetadata',
+    'PdfTimeStamper',
     'sign_pdf',
     'async_sign_pdf',
     'DEFAULT_MD'
