@@ -2,8 +2,10 @@
 from .pdf_embedded import (
     read_certification_data,
 )
+from .dss import DocumentSecurityStore
 
 __all__ = [
     'read_certification_data',
+    'DocumentSecurityStore'
 ]
 
